@@ -11,7 +11,7 @@ test_that("coef_map: two variables with the same name within or between models",
   y <- rnorm(100)
   z <- rnorm(100)
   mod <- lm(y ~ x + z)
-  expect_error(modelsummary(mod, "data.frame", coef_map = c('x' = 'X', 'z' = 'X')))
+  expect_warning(modelsummary(mod, "data.frame", coef_map = c('x' = 'X', 'z' = 'X')))
 
   # across models works well
   mod <- list()
